**Example 1: 禁用设备**



Input: 

```
tccli iotvideo DisableDevice --cli-unfold-argument  \
    --Tids xxx0 xxx1 xxx2
```

Output: 
```
{
    "Response": {
        "RequestId": "9396ceb0-4abd-4b8a-b991-abff1131c334"
    }
}
```

